@@ -21,7 +21,7 @@ class Formatter:
 		- delta		A time delta object
 		- as_dict	Whether it should return a dictionary or a string. Default False
 		
-		return		String or disctoonary according to as_dict kwarg
+		return		String or dictionary according to as_dict kwarg
 		"""
 		
 		if not isinstance(delta, dt.timedelta):
@@ -102,7 +102,7 @@ class Formatter:
 		- past		A datetime.date or datetime.datetime object represents a past date. Giving future date will raise an error.
 		- as_dict	Whether it should return a dictionary or a string. Default False
 		
-		return		String or disctoonary according to as_dict kwarg
+		return		String or dictionary according to as_dict kwarg
 		"""
 		valids = [dt.date, dt.datetime]
 		
@@ -197,7 +197,7 @@ class Formatter:
 		- datetime2	A datetime.date or datetime.datetime object
 		- as_dict	 	Whether it should return a dictionary or a string. Default False
 		
-		return		String or disctoonary according to as_dict kwarg
+		return		String or dictionary according to as_dict kwarg
 		"""
 		valids = [dt.date, dt.datetime]
 		
